//@line 36 "/builds/slave/tb-rel-c-beta-l64_rpk_4-000000/l10n/ga-IE/calendar/lightning-l10n.js"

//@line 38 "/builds/slave/tb-rel-c-beta-l64_rpk_4-000000/l10n/ga-IE/calendar/lightning-l10n.js"

//@line 41 "/builds/slave/tb-rel-c-beta-l64_rpk_4-000000/l10n/ga-IE/calendar/lightning-l10n.js"
pref("calendar.week.start", 0);

//@line 44 "/builds/slave/tb-rel-c-beta-l64_rpk_4-000000/l10n/ga-IE/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "ga-IE");

//@line 55 "/builds/slave/tb-rel-c-beta-l64_rpk_4-000000/l10n/ga-IE/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Cothrom Lae,Breithlá,Gnó,Glaonna,Cliaint,Iomaitheoirí,Custaiméir,Ceanáin,Le Déanamh,Bronntanais,Laethanta Saoire,Smaointe,Fadhbanna,Éagsúil,Pearsanta,Tionscadail,Lá Saoire Bainc,Stádas,Soláthraithe,Taisteal,Saoire");
